NoCalcNumeric

Enum NoCalcNumeric 

#[repr(u8)]
pub enum NoCalcNumeric { Length(NoCalcLength), Number(Number), Percentage(Percentage), }
A numeric value without a calc expression.

Variants

Implementations

Source

impl NoCalcNumeric

pub fn unitless_value(&self) -> CSSFloat

Return the unitless, raw value.

pub fn unit(&self) -> &'static str

Return the unit, as a string.

TODO: Investigate returning SortKey or adding a new variant for returning the unit as SortKey. Tracked in https://bugzilla.mozilla.org/show_bug.cgi?id=2015863

pub fn canonical_unit(&self) -> Option<&'static str>

Return the canonical unit for this value, if one exists.

TODO: Investigate returning SortKey. Tracked in https://bugzilla.mozilla.org/show_bug.cgi?id=2015863

pub fn to(&self, unit: &str) -> Result<Self, ()>

Convert this value to the specified unit, if possible.

TODO: Investigate using SortKey. Tracked in https://bugzilla.mozilla.org/show_bug.cgi?id=2015863

pub fn parse_unit_value(value: CSSFloat, unit: &str) -> Result<Self, ()>

Parse a given unit value.