#[repr(u8)]pub enum NoCalcNumeric {
Length(NoCalcLength),
Number(Number),
Percentage(Percentage),
}Expand description
A numeric value without a calc expression.
Variants
Length(NoCalcLength)
A <length> value.
Number(Number)
A <number> value.
Percentage(Percentage)
A <percentage> value.
Implementations
Sourceimpl NoCalcNumeric
impl NoCalcNumeric
Sourcepub fn unitless_value(&self) -> CSSFloat
pub fn unitless_value(&self) -> CSSFloat
Return the unitless, raw value.
Sourcepub fn unit(&self) -> &'static str
pub fn unit(&self) -> &'static str
Return the unit, as a string.
TODO: Investigate returning SortKey or adding a new variant for returning the unit as SortKey. Tracked in https://bugzilla.mozilla.org/show_bug.cgi?id=2015863
Sourcepub fn canonical_unit(&self) -> Option<&'static str>
pub fn canonical_unit(&self) -> Option<&'static str>
Return the canonical unit for this value, if one exists.
TODO: Investigate returning SortKey. Tracked in https://bugzilla.mozilla.org/show_bug.cgi?id=2015863